let deviceUtil = {}
deviceUtil.transDbDataToSelectShow = function (data, valueKey, labelKey) { // 构造页面展示数据
  var results = []
  if (data) {
    data.forEach((oneData, index) => {
      var result = {}
      result.value = oneData[valueKey]
      result.label = oneData[labelKey]
      results[index] = result
    })
  }
  return results
}

/**
 * 处理数据，无子节点展示为叶子
 * @param data  原始数据
 * @returns {Array} 返回数据
 */
deviceUtil.transTreeShowLeaf = function (data) { // 构造页面展示数据
  if (data) {
    data.forEach((oneData, index) => {
      var children = oneData.children
      if (this.isEmpty(children)) {
        delete oneData.children
        delete oneData.loading
      }
    })
  }
}
deviceUtil.transDbDataToArray = function (data, valueKey) { // 构造页面展示数据
  var results = []
  if (data) {
    data.forEach((oneData, index) => {
      var value = oneData[valueKey]
      results[index] = value
    })
  }
  return results
}

deviceUtil.stringIsEmpty = function (value) { // 构造页面展示数据
  var result = false
  if (value) {
    if (value == null) {
      result = true
    } else if (value == '') {
      result = true
    }
  } else {
    result = true
  }
  return result
}

deviceUtil.stringIsNotEmpty = function (value) { // 构造页面展示数据
  return !this.stringIsEmpty(value)
}

deviceUtil.isEmpty = function (value) { // 构造页面展示数据
  var result = false
  if (!value || value == null || value == '') {
    result = true
  } else if (Array.isArray(value) && value.length == 0) {
    result = true
  } else if (typeof (value) == 'object') { // 对象
    return false// 如果是对象 直接返回
  }
  return result
}

deviceUtil.isNotEmpty = function (value) { // 构造页面展示数据
  if (value) {
    return !this.isEmpty(value)
  } else {
    return false
  }
}

deviceUtil.transDbDataToTreeShow = function (data, idKey, titleKey, treeType, parentId, companyId, hasChild) { // 构造页面展示数据
  let results = []
  if (this.isNotEmpty(data)) {
    data.forEach((oneData, index) => {
      var result = {}
      result.id = oneData[idKey]
      result.title = oneData[titleKey]
      result.treeType = treeType
      result.parentId = parentId
      result.companyId = companyId
      if (oneData['hasChild'] || hasChild) {
        result.children = []
        result.loading = false
      }
      results[index] = result
    })
  } else {
    var result = {}
    result.parentId = parentId
    result.id = 0
    result.title = '空'
    results[0] = result
  }
  return results
}

deviceUtil.getCurrentMonthFirst = function () {
  var date = new Date()
  date.setDate(1)
  date.setHours(0)
  date.setMinutes(0)
  date.setSeconds(0)
  return date
}

deviceUtil.getMonthFirst = function (date) {
  date.setDate(1)
  date.setHours(0)
  date.setMinutes(0)
  date.setSeconds(0)
  return date
}

deviceUtil.getCurrentMonthLast = function () {
  var date = new Date()
  var currentMonth = date.getMonth()
  var nextMonth = ++currentMonth
  var nextMonthFirstDay = new Date(date.getFullYear(), nextMonth, 1, 23, 59, 59)
  var oneDay = 1000 * 60 * 60 * 24
  return new Date(nextMonthFirstDay - oneDay)
}
deviceUtil.getMonthLast = function (date) {
  var currentMonth = date.getMonth()
  var nextMonth = ++currentMonth
  var nextMonthFirstDay = new Date(date.getFullYear(), nextMonth, 1, 23, 59, 59)
  var oneDay = 1000 * 60 * 60 * 24
  return new Date(nextMonthFirstDay - oneDay)
}

// 2018-06-01
deviceUtil.formatDate = function (date, space = '-') {
  return `${this.formatNumber(date.getFullYear())}${space}${this.formatNumber(1 + date.getMonth())}${space}${this.formatNumber(date.getDate())}`
}

// 2018-06
deviceUtil.formatMonth = function (date = new Date(), space = '-') {
  return `${this.formatNumber(date.getFullYear())}${space}${this.formatNumber(1 + date.getMonth())}`
}

deviceUtil.formatTime = function (date, space1 = '-', space2 = ':') {
  if (!date) console.error('date 参数为空')
  return `${this.formatNumber(date.getFullYear())}${space1}${this.formatNumber(1 + date.getMonth())}${space1}${this.formatNumber(date.getDate())} ${this.formatNumber(date.getHours())}${space2}${this.formatNumber(date.getMinutes())}${space2}${this.formatNumber(date.getSeconds())}`
}
deviceUtil.getCurrentTimePk = function () {
  var date = new Date()
  return `${this.formatNumber(date.getFullYear())}${this.formatNumber(1 + date.getMonth())}${this.formatNumber(date.getDate())}${this.formatNumber(date.getHours())}${this.formatNumber(date.getMinutes())}${this.formatNumber(date.getSeconds())}`
}
// 格式化数字
deviceUtil.formatNumber = function (num) {
  return num > 9 ? num : '0' + num
}

// 格式化数字
deviceUtil.error = function (self, message = '操作失败') {
  self.$Modal.error({ title: '错误', content: message })
}

// 格式化数字
deviceUtil.info = function (self, message = '操作提示') {
  self.$Modal.info({ title: '提示', content: message })
}

// 格式化数字
deviceUtil.warning = function (self, message = '操作警告') {
  self.$Modal.warning({ title: '警告', content: message })
}

deviceUtil.show = function (self, message = '内容', title = '展示') {
  self.$Modal.info({
    title: title,
    content: message,
    okText: '关闭'
  })
}

deviceUtil.confirm = function (self, content = '确认操作码？', callback) {
  self.$Modal.confirm({
    title: '提示',
    content: '<h5>' + content + '</h5>',
    onOk: () => {
      callback()
    },
    onCancel: function () {
    }
  })
}

deviceUtil.check = function (res) {
  var result = false
  if (res.status && res.status == 200) { // 成功
    result = true
  } else {
    console.error('接口调用错误:')
    console.error(res)
  }
  return result
}

deviceUtil.checkSuccess = function (res) {
  var result = false
  if (res.status == 200) { // 成功
    if (res.message == 'success' || res.success == true) {
      result = true
    }
  }
  if (!result) {
    console.error(res)
  }
  return result
}

deviceUtil.checkGetString = function (value, def = '00') {
  var result = def
  if (value) {
    if (value != null && value != '' && value != 'null') {
      result = value
    }
  }
  return result
}

deviceUtil.checkGetBoolean = function (value, def = false) {
  var result = def
  if (value || value == 'true') {
    result = true
  }
  return result
}

deviceUtil.findData = function (res) {
  var data = []
  if (this.check(res)) {
    data = res.data == null ? [] : res.data
  }
  return data
}

deviceUtil.findPageDataWithCount = function (res) {
  var data = []
  if (this.check(res) && res.data) {
    data = res.data == null ? [] : res.data
  }
  return data
}

deviceUtil.findPageData = function (res) {
  var data = []
  if (this.check(res) && res.data) {
    data = res.data.records == null ? [] : res.data.records
  }
  return data
}
deviceUtil.findPageTotal = function (res) {
  if (res.data) {
    return res.data.total
  }
  return 0
}

deviceUtil.stringToArray = function (datas) {
  var dataArray = []
  if (this.stringIsNotEmpty(datas)) {
    dataArray = datas.split(',')
  }
  return dataArray
}

deviceUtil.stringToArrayNames = function (datas, map) {
  var dataNameArray = []
  if (this.stringIsNotEmpty(datas)) {
    var dataArray = datas.split(',')
    dataArray.forEach((item, index) => {
      if (this.isNotEmpty(item) && map[item]) {
        dataNameArray.push(map[item])
      }
    })
  }
  return this.arrayToString(dataNameArray)
}

// 将数组装换未string  逗号分割
deviceUtil.arrayToString = function (arrayParam) {
  if (!arrayParam) {
    console.error('arrayToString 参数为空')
  }
  var stringParam = ''
  var arrayLength = arrayParam.length
  arrayParam.forEach((oneValue, index) => {
    stringParam = stringParam + oneValue
    if (index < arrayLength - 1) {
      stringParam += ','
    }
  })
  return stringParam
}

deviceUtil.toDomain = function (data) {
  return {'domain': JSON.stringify(data)}
}

deviceUtil.clone = function (data) {
  return JSON.parse(JSON.stringify(data))
}

deviceUtil.subShow = function (str, subIndex) {
  var r = ''
  if (str && str.length > subIndex) {
    r = str.substring(0, subIndex) + '...'
  } else {
    r = str
  }
  return r
}

/**
 * 异步列表查询列表延时加载。每0.1秒进行一次尝试，如果checkF校验成功  调用callbackF方法
 * @param n 循环当前次数
 * @param callbackF 异步调用的主函数
 * @param checkF    校验函数
 * @param timeInterval 默认100毫秒
 * @param maxIndex 默认最大次数10   最大等待时间10 * 100毫秒 = 1秒
 * @author yangsumeng 20180905
 */
deviceUtil.initTableTimeOut = function (callbackFun, checkFun, n = 0, timeInterval = 100, maxIndex = 10) {
  if (n++ < maxIndex) {
    setTimeout(() => {
      if (checkFun()) {
        console.log('initTableTimeOut ok') // 初始化完成 执行查询，防止请求数据太多
        callbackFun()
      } else {
        console.log('initTableTimeOut....') // 等待执行 最多maxIndex次
        this.initTableTimeOut(callbackFun, checkFun, n, timeInterval, maxIndex)
      }
    }, timeInterval)
  } else {
    console.error('数据异步初始化失败，等待时间（毫秒）：' + timeInterval * maxIndex)
  }
}

export default deviceUtil
