import axios from 'axios'
import {
  getToken
} from '@/utils/auth'
// import {Spin} from 'view-design'
import {
  Notice,
  LoadingBar,
  Message
} from 'view-design'
import Router from '../router'
import store from '@/store'

/**
 * 使用自定义配置新建一个 axios 实例
 * baseURL = 请求路径
 * timeout = 请求超时配置
 */
const request = axios.create({
  baseURL: process.env.BASE_API,
  timeout: process.env.TIME_OUT
})
let spinTime = 0
/**
 * request拦截器
 * 可以在这里添加 Header 头部信息，等
 */
request.interceptors.request.use(config => {
  //  显示加载
  if (spinTime == 0) {
    // Spin.show()
    store.state.common.buttonLoading = true
    LoadingBar.start()
  }
  spinTime++
  //  获取accessToken
  let accessToken = localStorage.getItem('token')
  //  添加请求头信息，处理安全性问题
  if (accessToken != undefined) {
    config.headers.Authorization = 'Bearer ' + accessToken
    // config.headers.Authorization = 'Bearer 8f5eea08710b6ef32ed48b1287ea3337' // 郭佳登录token
  } else {
    config.headers.Authorization = 'Basic dnVlOnZ1ZQ=='
  }
  //  添加时间戳防止IE不刷新页面
  if (config.type != 'FORM') {
    if (config.method == 'post') {
      // config.data = {
      //   ...config.data
      // }
    } else if (config.method == 'get') {
      config.params = {
        ...config.params,
        _t: Date.parse(new Date()) / 1000
      }
    }
  } else {
    let formData = ''
    Object.keys(config.data).forEach((key) => {
      formData += key + '=' + config.data[key] + '&'
    })
    config.data = formData
    config.headers['Accept'] = 'application/json'
    config.headers['Content-Type'] = 'application/x-www-form-urlencoded'
  }
  return config
}, error => {
  // 处理请求错误
  Promise.reject(error)
})

/**
 * 下面的注释为通过response自定义code来标示请求状态，当coBASE_APIde返回如下情况为权限有问题，登出并返回到登录页
 * 如通过xmlhttprequest 状态码标识 逻辑可写在下面error中
 */
request.interceptors.response.use(
  response => {
    //  隐藏加载
    spinTime--
    setTimeout(() => {
      if (spinTime == 0) {
        // Spin.hide()
        store.state.common.buttonLoading = false
        LoadingBar.finish()
      }
    }, 0)
    // 请求成功处理
    const res = response.data
    if (res.status != 10000) {
      Message.error(res.message)
    }
    if (res.status == 401) {
      Router.push('/')
    }
    return res
  },
  error => {
    //  隐藏加载
    spinTime--
    setTimeout(() => {
      if (spinTime == 0) {
        // Spin.hide()
        store.state.common.buttonLoading = false
        LoadingBar.finish()
      }
    }, 0)
    // 处理请求错误
    const response = error.response
    if (response != undefined && response.data) {
      if (response.data.statusCode == '40206' && response.status == 400) {
        Notice.error({
          title: response.data.message
        })
      } else if (response.data.statusCode == '40201' && response.status == 400) {
        Notice.error({
          title: response.data.message
        })
      } else if (response.data.statusCode == '40202' && response.status == 400) {
        Notice.error({
          title: response.data.message
        })
      } else if (response.data.statusCode == '40207' && response.status == 400) {
        Notice.error({
          title: response.data.message
        })
      } else if (response.data.statusCode == '40208' && response.status == 400) {
        Notice.error({
          title: response.data.message
        })
      } else if (response.data.statusCode == '40209' && response.status == 400) {
        Notice.error({
          title: response.data.message
        })
      } else if (response.data.statusCode == '40203' && response.status == 400) {
        Notice.error({
          title: response.data.message
        })
      } else if (response.data.statusCode == '401' && response.status == 401) {
        Notice.error({
          title: '凭证过期，请重新登录'
        })
        Router.push('/')
      } else if (response.status == 500) {
        Notice.error({
          title: response.data.message
        })
      } else if (response.data.statusCode != '200' && response.status != 200) {
        Notice.error({
          title: `连接错误${error.response.status}`
        })
      }
      // return response.data
    } else if (response) {
      switch (response.status) {
        case 400:
          error.message = '错误的请求'
          break
        case 401:
          Notice.error({
            title: '凭证过期，请重新登录'
          })
          break
        case 403:
          Notice.error({
            title: '拒绝访问'
          })
          break
        case 404:
          Notice.error({
            title: '请求错误,未找到该资源'
          })
          break
        case 405:
          Notice.error({
            title: '请求方法未允许'
          })
          break
        case 408:
          Notice.error({
            title: '请求超时'
          })
          break
        case 500:
          Notice.error({
            title: '服务器端出错'
          })
          break
        case 501:
          Notice.error({
            title: '网络错误，请检查网络'
          })
          break
        case 502:
          Notice.error({
            title: '网络错误，请检查网络'
          })
          break
        case 503:
          Notice.error({
            title: '服务不可用'
          })
          break
        case 504:
          Notice.error({
            title: '网络请求超时'
          })
          break
        case 505:
          Notice.error({
            title: 'http版本不支持该请求'
          })
          break
        default:
          Notice.error({
            title: `连接错误${error.response.status}`
          })
      }
    } else {
      Notice.error({
        title: error.message
      })
    }
    // 弹出层
    return Promise.reject(error)
  }
)

export default request
